package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnCultureKnowledge;

/**
 * 文化知识点关系Service接口
 * 
 * @author ruoyi
 * @date 2025-12-02
 */
public interface ILearnCultureKnowledgeService 
{
    /**
     * 查询文化知识点关系
     * 
     * @param id 文化知识点关系主键
     * @return 文化知识点关系
     */
    public LearnCultureKnowledge selectLearnCultureKnowledgeById(Long id);

    /**
     * 查询文化知识点关系列表
     * 
     * @param learnCultureKnowledge 文化知识点关系
     * @return 文化知识点关系集合
     */
    public List<LearnCultureKnowledge> selectLearnCultureKnowledgeList(LearnCultureKnowledge learnCultureKnowledge);

    /**
     * 新增文化知识点关系
     * 
     * @param learnCultureKnowledge 文化知识点关系
     * @return 结果
     */
    public int insertLearnCultureKnowledge(LearnCultureKnowledge learnCultureKnowledge);

    /**
     * 修改文化知识点关系
     * 
     * @param learnCultureKnowledge 文化知识点关系
     * @return 结果
     */
    public int updateLearnCultureKnowledge(LearnCultureKnowledge learnCultureKnowledge);

    /**
     * 批量删除文化知识点关系
     * 
     * @param ids 需要删除的文化知识点关系主键集合
     * @return 结果
     */
    public int deleteLearnCultureKnowledgeByIds(Long[] ids);

    /**
     * 删除文化知识点关系信息
     * 
     * @param id 文化知识点关系主键
     * @return 结果
     */
    public int deleteLearnCultureKnowledgeById(Long id);
}
