package com.ruoyi.web.controller.learn;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.learn.domain.LearnCultureKnowledge;
import com.ruoyi.learn.service.ILearnCultureKnowledgeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 文化知识点关系Controller
 * 
 * @author ruoyi
 * @date 2025-12-02
 */
@RestController
@RequestMapping("/learn/learnCultureKnowledge")
public class LearnCultureKnowledgeController extends BaseController
{
    @Autowired
    private ILearnCultureKnowledgeService learnCultureKnowledgeService;

    /**
     * 查询文化知识点关系列表
     */
    @PreAuthorize("@ss.hasPermi('learn:learnCultureKnowledge:list')")
    @GetMapping("/list")
    public TableDataInfo list(LearnCultureKnowledge learnCultureKnowledge)
    {
        startPage();
        List<LearnCultureKnowledge> list = learnCultureKnowledgeService.selectLearnCultureKnowledgeList(learnCultureKnowledge);
        return getDataTable(list);
    }

    /**
     * 导出文化知识点关系列表
     */
    @PreAuthorize("@ss.hasPermi('learn:learnCultureKnowledge:export')")
    @Log(title = "文化知识点关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LearnCultureKnowledge learnCultureKnowledge)
    {
        List<LearnCultureKnowledge> list = learnCultureKnowledgeService.selectLearnCultureKnowledgeList(learnCultureKnowledge);
        ExcelUtil<LearnCultureKnowledge> util = new ExcelUtil<LearnCultureKnowledge>(LearnCultureKnowledge.class);
        util.exportExcel(response, list, "文化知识点关系数据");
    }

    /**
     * 获取文化知识点关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('learn:learnCultureKnowledge:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(learnCultureKnowledgeService.selectLearnCultureKnowledgeById(id));
    }

    /**
     * 新增文化知识点关系
     */
    @PreAuthorize("@ss.hasPermi('learn:learnCultureKnowledge:add')")
    @Log(title = "文化知识点关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LearnCultureKnowledge learnCultureKnowledge)
    {
        return toAjax(learnCultureKnowledgeService.insertLearnCultureKnowledge(learnCultureKnowledge));
    }

    /**
     * 修改文化知识点关系
     */
    @PreAuthorize("@ss.hasPermi('learn:learnCultureKnowledge:edit')")
    @Log(title = "文化知识点关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LearnCultureKnowledge learnCultureKnowledge)
    {
        return toAjax(learnCultureKnowledgeService.updateLearnCultureKnowledge(learnCultureKnowledge));
    }

    /**
     * 删除文化知识点关系
     */
    @PreAuthorize("@ss.hasPermi('learn:learnCultureKnowledge:remove')")
    @Log(title = "文化知识点关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(learnCultureKnowledgeService.deleteLearnCultureKnowledgeByIds(ids));
    }
}
